@@ -22,7 +22,8 @@ def evaluate_nll(input_file:str, poi_val:float, poi:str="", vmin:float=10., vmax
                  profile:str="", fix:str="", hesse:bool=False, minos:bool=True, constrain:bool=True, 
                  minimizer_type:str='Minuit2', minimizer_algo:str='Migrad', num_cpu:int=1, binned:bool=True,
                  eps:float=1.0, strategy:int=0, fix_cache:bool=True, fix_multi:bool=True, mpsplit:int=3, 
-                 max_calls:int=-1, max_iters:int=-1, optimize:bool=True, offset:bool=False, outname:str=None, cache:bool=False):
+                 verbose:int=0, max_calls:int=-1, max_iters:int=-1, optimize:bool=True, offset:bool=False, 
+                 outname:str=None, cache:bool=False):
     if cache:
         cached_result = load_cache(outname)
         if cached_result is not None:
@@ -109,7 +110,7 @@ def scan_nll(input_file:str, poi_min:float, poi_max:float, poi_step:float, poi:s
              profile:str="", fix:str="", hesse:bool=False, minos:bool=True, constrain:bool=True,
              minimizer_type:str='Minuit2', minimizer_algo:str='Migrad', num_cpu:int=1, binned:bool=True,
              eps:float=1.0, strategy:int=0, fix_cache:bool=True, fix_multi:bool=True, mpsplit:int=3, 
-             max_calls:int=-1, max_iters:int=-1, optimize:bool=True, offset:bool=False, parallel:int=8):
+             verbose:int=0, max_calls:int=-1, max_iters:int=-1, optimize:bool=True, offset:bool=False, parallel:int=8):
     start_time = time.time()
     points        = np.arange(poi_min, poi_max+poi_step, poi_step)
     unconditional = np.concatenate(([True], np.full((len(points)), False)))
@@ -134,7 +135,7 @@ def scan_nll(input_file:str, poi_min:float, poi_max:float, poi_step:float, poi:s
                      repeat(snapshot), repeat(profile), repeat(fix), repeat(hesse), repeat(minos),
                      repeat(constrain), repeat(minimizer_type), repeat(minimizer_algo), repeat(num_cpu),
                      repeat(binned), repeat(eps), repeat(strategy), repeat(fix_cache),
-                     repeat(fix_multi), repeat(mpsplit), repeat(max_calls), repeat(max_iters), 
+                     repeat(fix_multi), repeat(mpsplit), repeat(verbose), repeat(max_calls), repeat(max_iters), 
                      repeat(optimize), repeat(offset), outnames, repeat(cache)) 
         max_workers = parallel if parallel != -1 else common_utils.get_cpu_count()
         results = common_utils.parallel_run(evaluate_nll, *arguments, max_workers=max_workers)
@@ -143,7 +144,7 @@ def scan_nll(input_file:str, poi_min:float, poi_max:float, poi_step:float, poi:s
         for point, uncond, outname_ in zip(points, unconditional, outnames):
             nll = evaluate_nll(input_file, point, poi, vmin, vmax, uncond, workspace, model_config, data,
                                snapshot, profile, fix, hesse, minos, constrain, minimizer_type, minimizer_algo,
-                               num_cpu, binned, eps, strategy, fix_cache, fix_multi, mpsplit, max_calls,
+                               num_cpu, binned, eps, strategy, fix_cache, fix_multi, mpsplit, verbose, max_calls,
                                max_iters, optimize, offset, outname_, cache)
             results.append(nll)
     uncond_nll = results[0]
