@@ -288,7 +288,7 @@ class NuisanceParameterPull(object):
                    fix_param:str='', profile_param:str='', binned:bool=True,
                    minimizer_type:str='Minuit2', minimizer_algo:str='Migrad', 
                    precision:float=0.001, eps:float=1.0, strategy:int=0, 
-                   num_cpu:int=1, offset:int=1, optimize:int=2, eigen:bool=False,
+                   num_cpu:int=1, offset:bool=True, optimize:bool=True, eigen:bool=False,
                    fix_cache:bool=True, fix_multi:bool=True, max_calls:int=-1, 
                    max_iters:int=-1, outdir:str='output', cache=True, **kwargs):
         outname_root = os.path.join(outdir, nuis_name + '.root')
@@ -298,11 +298,10 @@ class NuisanceParameterPull(object):
             print('INFO: Jobs already finished for the NP: {}. Skipping.'.format(nuis_name))
             return None
         start_time = time.time()
-        snapshot_names = snapshot.split(',')
         # load model
-        model = ExtendedModel(model_name="model", fname=input_file, ws_name=workspace,
+        model = ExtendedModel(fname=input_file, ws_name=workspace,
                               model_config_name=model_config, data_name=data, 
-                              snapshot_names=snapshot_names, binned_likelihood=binned,
+                              snapshot_name=snapshot, binned_likelihood=binned,
                               tag_as_measurement="pdf_", fix_cache=fix_cache, fix_multi=fix_multi)
         if fix_param:
             model.fix_parameters(fix_param)
@@ -469,12 +468,13 @@ class NuisanceParameterPull(object):
         
 
         
-    def run_pulls(self, input_file='workspace.root', workspace='combWS', model_config='ModelConfig',
-                 data='combData', poi='', snapshot='nominalNuis', outdir='output', profile="",
-                 fix='', minimizer_type='Minuit2', minimizer_algo='Migrad', num_cpu=1, binned=1,
-                 precision=0.001, eps=1.0, log_level='INFO', eigen=0, strategy=0, fix_cache=1, fix_multi=1,
-                 offset=1, optimize=2, parameter="", max_calls=-1, max_iters=-1, parallel=0, cache=True, 
-                 exclude='', **kwargs):
+    def run_pulls(self, input_file:str='workspace.root', workspace:str='combWS', model_config:str='ModelConfig',
+                  data:str='combData', poi:str='', snapshot:str='nominalNuis', outdir:str='output', profile:str="",
+                  fix:str='', minimizer_type:str='Minuit2', minimizer_algo:str='Migrad', num_cpu:int=1, 
+                  binned:bool=1, precision:float=0.001, eps:float=1.0, log_level:str='INFO', eigen:bool=False, 
+                  strategy:int=0, fix_cache:bool=True, fix_multi:bool=True, offset:bool=True, optimize:bool=True,
+                  parameter:str="", max_calls:int=-1, max_iters:int=-1, parallel:int=0, cache:bool=True, 
+                  exclud:str='', **kwargs):
         
         start_time = time.time()
         
